/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Pierre Garcia
 */

package org.objectweb.dream.dreamannotation.generator.template.lifecycle;

import org.objectweb.dream.control.lifecycle.PrepareStopLifeCycleController;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

import spoon.reflect.code.CtInvocation;
import spoon.reflect.declaration.CtClass;
import spoon.reflect.declaration.CtMethod;
import spoon.reflect.reference.CtExecutableReference;
import spoon.template.Local;
import spoon.template.Parameter;
import spoon.template.Template;

/**
 * A template code to manage the DreamLifeCycle annotation when the
 * <code>on</code> parameter is equal to
 * <code>{@link DreamLifeCycleType.PREPARE_TO_STOP}</code>. This annotation
 * must be above a method without arguments returning void This template
 * introdudes the implementation of the PrepareStop controller.
 * 
 * @author Pierre Garcia <Pierre.Garcia@inrialpes.fr>
 */
public class DreamLifeCyclePrepareStopTemplate
    implements
      PrepareStopLifeCycleController,
      Template
{

  @SuppressWarnings("unchecked")
  @Local
  public DreamLifeCyclePrepareStopTemplate(CtMethod<?> processedMethod)
  {
    _methodCall_ = processedMethod.getFactory().Core().createInvocation();
    _methodCall_.setTarget(processedMethod.getFactory().Code()
        .createThisAccess(
            processedMethod.getFactory().Type().createReference(
                processedMethod.getParent(CtClass.class).getActualClass())));
    _methodCall_.setExecutable((CtExecutableReference) processedMethod
        .getReference());
  }

  @Parameter
  CtInvocation<?> _methodCall_;

  /**
   * @see org.objectweb.dream.control.lifecycle.PrepareStopLifeCycleController#prepareStopFc()
   */
  public void prepareStopFc() throws IllegalLifeCycleException
  {
    try
    {
      _methodCall_.S();
    }
    catch (Exception e)
    {
      throw new IllegalLifeCycleException(e.getMessage());
    }
  }
}
