#!/bin/sh

RepScript=`dirname $0`
RepCourant=`pwd`

usage()
{
    echo "The clean.sh script is used to clean Petals."
    echo "usage : clean.sh [-h|-y]"
    echo "     -h : prints the help message"
    echo "     -y : no confirmation is asked"
    exit 0;
}

clean_petals()
{
	REPOSITORY_PATH=`grep "^[^#]*repository.path" $PETALS_HOME/conf/server.properties | awk 'BEGIN { FS="=" } { print $2 }' | sed 's/
$//'`
	if [ "$REPOSITORY_PATH" = "" ]
	then
		REPOSITORY_PATH=$PETALS_HOME/repository
	fi

	JORAM_PATH=`grep "^[^#]*joram.path" $PETALS_HOME/conf/server.properties | awk 'BEGIN { FS="=" } { print $2 }' | sed 's/
$//'`
	if [ "$JORAM_PATH" = "" ]
	then
		JORAM_PATH=$PETALS_HOME/joram
	fi

	echo "Repository Path: $REPOSITORY_PATH"
	echo "Joram Path: $JORAM_PATH"

	rm -f $PETALS_HOME/locked
	rm -rf $PETALS_HOME/install/*
	rm -rf $PETALS_HOME/installed/*
	rm -rf $PETALS_HOME/lost+found/*
	rm -rf $REPOSITORY_PATH/shared-libraries/*
	rm -rf $REPOSITORY_PATH/components/*
	rm -rf $REPOSITORY_PATH/service-assemblies/*
	rm -f $REPOSITORY_PATH/system-state.xml
	rm -rf $PETALS_HOME/uninstalled/*
	rm -rf $PETALS_HOME/logs/*
	rm -rf $PETALS_HOME/work/*
	rm -rf $JORAM_PATH/[0-9]*
}

# arguments analysis
Confirmed=false
while getopts :hv:yv options
do
        case ${options} in
                h)
                        usage
                        ;;
                y)
                        Confirmed=true
                        ;;
        esac
done


echo "Setting Petals environment"
######################################
#   ENV VARIABLES
######################################

if [ -z $PETALS_HOME ]
then
	PETALS_HOME=$RepCourant/$RepScript/../
fi

if [ ! -f $PETALS_HOME/conf/server.properties ]
then
	echo "The PETALS_HOME environment variable cannot be set correctly. Please set it in your environment with the correct value."
	exit 2
fi

#####################################

if [ "$Confirmed" = "false" ]
then
	echo "Are you sure to clean this PEtALS instance (Y/n) ?"
	read ANSWER
	if [ "$ANSWER" = "Y" ]
	then
		Confirmed=true
	fi
fi

if [ "$Confirmed" = "true" ]
then
	clean_petals
else
	echo "Clean canceled."
fi

exit 0
